@@ -16,7 +16,6 @@ from .utils import (
     get_idf_dict,
     bert_cos_score_idf,
     get_bert_embedding,
-    model_types,
     lang2model,
     model2layers,
     get_hash,
@@ -104,7 +103,8 @@ def score(
         tokenizer = AutoTokenizer.from_pretrained(model_type)
 
     model = get_model(model_type, num_layers, all_layers)
-    device = "cuda" if torch.cuda.is_available() else "cpu"
+    if device is None:
+        device = "cuda" if torch.cuda.is_available() else "cpu"
     model.to(device)
 
     if not idf:
@@ -141,8 +141,8 @@ def score(
 
     if ref_group_boundaries is not None:
         max_preds = []
-        for start, end in ref_group_boundaries:
-            max_preds.append(all_preds[start:end].max(dim=0)[0])
+        for beg, end in ref_group_boundaries:
+            max_preds.append(all_preds[beg:end].max(dim=0)[0])
         all_preds = torch.stack(max_preds, dim=0)
 
     if rescale_with_baseline:
