@@ -8,6 +8,7 @@ from multiprocessing import Pool
 from functools import partial
 from tqdm.auto import tqdm
 from torch.nn.utils.rnn import pad_sequence
+from distutils.version import LooseVersion
 
 from transformers import BertConfig, XLNetConfig, XLMConfig, RobertaConfig
 from transformers import AutoModel, GPT2Tokenizer
@@ -15,7 +16,7 @@ from transformers import AutoModel, GPT2Tokenizer
 from . import __version__
 from transformers import __version__ as trans_version
 
-__all__ = ["model_types"]
+__all__ = []
 
 SCIBERT_URL_DICT = {
     "scibert-scivocab-uncased": "https://s3-us-west-2.amazonaws.com/ai2-s2-research/scibert/pytorch_models/scibert_scivocab_uncased.tar",  # recommend by the SciBERT authors
@@ -24,13 +25,6 @@ SCIBERT_URL_DICT = {
     "scibert-basevocab-cased": "https://s3-us-west-2.amazonaws.com/ai2-s2-research/scibert/pytorch_models/scibert_basevocab_cased.tar",
 }
 
-model_types = (
-    list(BertConfig.pretrained_config_archive_map.keys())
-    + list(XLNetConfig.pretrained_config_archive_map.keys())
-    + list(RobertaConfig.pretrained_config_archive_map.keys())
-    + list(XLMConfig.pretrained_config_archive_map.keys())
-    + list(SCIBERT_URL_DICT.keys())
-)
 
 lang2model = defaultdict(lambda: "bert-base-multilingual-cased")
 lang2model.update(
@@ -111,9 +105,17 @@ def sent_encode(tokenizer, sent):
         return tokenizer.build_inputs_with_special_tokens([])
     elif isinstance(tokenizer, GPT2Tokenizer):
         # for RoBERTa and GPT-2
-        return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len)
+        import transformers
+        if LooseVersion(transformers.__version__) >= LooseVersion("3.0.0"):
+            return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len, truncation=True)
+        else:
+            return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len)
     else:
-        return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.max_len)
+        import transformers
+        if LooseVersion(transformers.__version__) >= LooseVersion("3.0.0"):
+            return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.max_len, truncation=True)
+        else:
+            return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.max_len)
 
 
 def get_model(model_type, num_layers, all_layers=None):
@@ -343,11 +345,11 @@ def greedy_cos_idf(ref_embedding, ref_masks, ref_idf, hyp_embedding, hyp_masks,
         F = F.view(L, B)
 
     if torch.any(hyp_zero_mask):
-        print("Warning: Empty candidate sentence; Setting precision to be 0.", file=sys.stderr)
+        print("Warning: Empty candidate sentence detected; setting precision to be 0.", file=sys.stderr)
         P = P.masked_fill(hyp_zero_mask, 0.0)
 
     if torch.any(ref_zero_mask):
-        print("Warning: Empty candidate sentence; Setting recall to be 0.", file=sys.stderr)
+        print("Warning: Empty reference sentence detected; setting recall to be 0.", file=sys.stderr)
         R = R.masked_fill(ref_zero_mask, 0.0)
 
     F = F.masked_fill(torch.isnan(F), 0.0)
@@ -375,7 +377,7 @@ def bert_cos_score_idf(
     preds = []
 
     def dedup_and_sort(l):
-        return sorted(list(set(l)), key=lambda x: len(x.split(" ")))
+        return sorted(list(set(l)), key=lambda x: len(x.split(" ")), reverse=True)
 
     sentences = dedup_and_sort(refs + hyps)
     embs = []
@@ -401,6 +403,8 @@ def bert_cos_score_idf(
     def pad_batch_stats(sen_batch, stats_dict, device):
         stats = [stats_dict[s] for s in sen_batch]
         emb, idf = zip(*stats)
+        emb = [e.to(device) for e in emb]
+        idf = [i.to(device) for i in idf]
         lens = [e.size(0) for e in emb]
         emb_pad = pad_sequence(emb, batch_first=True, padding_value=2.0)
         idf_pad = pad_sequence(idf, batch_first=True)
@@ -411,22 +415,24 @@ def bert_cos_score_idf(
             base = torch.arange(max_len, dtype=torch.long).expand(len(lens), max_len)
             return base < lens.unsqueeze(1)
 
-        pad_mask = length_to_mask(lens)
-        return emb_pad.to(device), pad_mask.to(device), idf_pad.to(device)
+        pad_mask = length_to_mask(lens).to(device)
+        return emb_pad, pad_mask, idf_pad
 
     device = next(model.parameters()).device
     iter_range = range(0, len(refs), batch_size)
     if verbose:
         print("computing greedy matching.")
         iter_range = tqdm(iter_range)
-    for batch_start in iter_range:
-        batch_refs = refs[batch_start : batch_start + batch_size]
-        batch_hyps = hyps[batch_start : batch_start + batch_size]
-        ref_stats = pad_batch_stats(batch_refs, stats_dict, device)
-        hyp_stats = pad_batch_stats(batch_hyps, stats_dict, device)
 
-        P, R, F1 = greedy_cos_idf(*ref_stats, *hyp_stats, all_layers)
-        preds.append(torch.stack((P, R, F1), dim=-1).cpu())
+    with torch.no_grad():
+        for batch_start in iter_range:
+            batch_refs = refs[batch_start : batch_start + batch_size]
+            batch_hyps = hyps[batch_start : batch_start + batch_size]
+            ref_stats = pad_batch_stats(batch_refs, stats_dict, device)
+            hyp_stats = pad_batch_stats(batch_hyps, stats_dict, device)
+
+            P, R, F1 = greedy_cos_idf(*ref_stats, *hyp_stats, all_layers)
+            preds.append(torch.stack((P, R, F1), dim=-1).cpu())
     preds = torch.cat(preds, dim=1 if all_layers else 0)
     return preds
 
